@@ -42,8 +42,11 @@ proc_filelist()
       -name "*.xml" -o \
       -name "*.html" -o \
       -name "*.tex" -o \
+      -name "*.texi" -o \
       -name "*.man" -o \
       -name "*.py" -o \
+      -name "*.win" -o \
+      -name "*.dos" -o \
       -name "ALLEGRO" -o \
       -name "COPYING" -o \
       -name "INSTALL" -o \
@@ -64,7 +67,7 @@ proc_chmod()
 	-name "config.guess" -o \
 	-name "config.sub" -o \
 	-name "install-sh" -o \
-	-name "fix.sh" -o \
+	-name "*.sh" -o \
 	-name "liquidwar" -o \
 	-name "liquidwar-server" -o \
 	-name "liquidward" \
