@@ -61,11 +61,14 @@
 #include "mesh.h"
 #include "move.h"
 #include "time.h"
+#include "config.h"
 
 /*==================================================================*/
-/* types                                                            */
+/* constants                                                        */
 /*==================================================================*/
 
+#define LW_AUTOPLAY_RANDOM_LIMIT 10000
+
 /*==================================================================*/
 /* variables globales                                               */
 /*==================================================================*/
@@ -80,8 +83,8 @@ static int COMPUTER_PATH_WAIT[NB_TEAMS];
 
 /*------------------------------------------------------------------*/
 static void calculate_computer_path  ( int dst_x,
-                                     int dst_y,
-                                     int cursor)
+				       int dst_y,
+				       int cursor)
 {
   int team, src_x, src_y,pos,dir,x,y,dx,dy;
   MESH *path_mesh,*src_mesh;
@@ -101,69 +104,69 @@ static void calculate_computer_path  ( int dst_x,
   path_mesh=CURRENT_AREA[y*CURRENT_AREA_W+x].mesh;
   pos=sens=start=0;
   while (pos<COMPUTER_PATH_MAX
-        && path_mesh!=0
-        && path_mesh!=src_mesh)
-        {
-         dir=get_main_dir (path_mesh,team, sens, start);
+	 && path_mesh!=0
+	 && path_mesh!=src_mesh)
+    {
+      dir=get_main_dir (path_mesh,team, sens, start);
 
-         x+=(dx=FIGHTER_MOVE_X[table][dir][0]);
-         y+=(dy=FIGHTER_MOVE_Y[table][dir][0]);
+      x+=(dx=FIGHTER_MOVE_X[table][dir][0]);
+      y+=(dy=FIGHTER_MOVE_Y[table][dir][0]);
 
-         path_mesh=CURRENT_AREA[y*CURRENT_AREA_W+x].mesh;
-         if (path_mesh)
-            {
-             COMPUTER_PATH_KEYS[cursor][pos]=0;
-             if (dy>0)
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_UP;
-             if (dx<0)
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_RIGHT;
-             if (dy<0)
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_DOWN;
-             if (dx>0)
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_LEFT;
-             pos++;
-            }
-         start++;
-         if (start==NB_DIRS)
-            {
-             start=0;
-             sens=!sens;
-            }
-        }
+      path_mesh=CURRENT_AREA[y*CURRENT_AREA_W+x].mesh;
+      if (path_mesh)
+	{
+	  COMPUTER_PATH_KEYS[cursor][pos]=0;
+	  if (dy>0)
+	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_UP;
+	  if (dx<0)
+	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_RIGHT;
+	  if (dy<0)
+	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_DOWN;
+	  if (dx>0)
+	    COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_LEFT;
+	  pos++;
+	}
+      start++;
+      if (start==NB_DIRS)
+	{
+	  start=0;
+	  sens=!sens;
+	}
+    }
 
   if (path_mesh==src_mesh)
-     {
+    {
       while (pos < COMPUTER_PATH_MAX
-            && (x!=src_x || y!=src_y))
-            {
-             COMPUTER_PATH_KEYS[cursor][pos]=0;
+	     && (x!=src_x || y!=src_y))
+	{
+	  COMPUTER_PATH_KEYS[cursor][pos]=0;
  
-             if (y<src_y)
-                {
-                 y++;
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_UP;
-                }
-             if (x>src_x)
-                {
-                 x--;
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_RIGHT;
-                }
-             if (y>src_y)
-                {
-                 y--;
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_DOWN;
-                }
-             if (x<src_x)
-                {
-                 x++;
-                 COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_LEFT;
-                }
-             pos++;
-            }
+	  if (y<src_y)
+	    {
+	      y++;
+	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_UP;
+	    }
+	  if (x>src_x)
+	    {
+	      x--;
+	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_RIGHT;
+	    }
+	  if (y>src_y)
+	    {
+	      y--;
+	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_DOWN;
+	    }
+	  if (x<src_x)
+	    {
+	      x++;
+	      COMPUTER_PATH_KEYS[cursor][pos]+=CURSOR_KEY_LEFT;
+	    }
+	  pos++;
+	}
       COMPUTER_PATH_SIZE[cursor]=pos;
-     }
+    }
   else
-     COMPUTER_PATH_SIZE[cursor]=0;
+    COMPUTER_PATH_SIZE[cursor]=0;
 
   COMPUTER_PATH_WAIT[cursor]= COMPUTER_PATH_SIZE[cursor];
 }
@@ -171,83 +174,105 @@ static void calculate_computer_path  ( int dst_x,
 /*------------------------------------------------------------------*/
 void reset_computer_path  (void)
 {
- int i;
+  int i;
 
- for (i=0;i<NB_TEAMS;++i)
-     {
+  for (i=0;i<NB_TEAMS;++i)
+    {
       COMPUTER_PATH_SIZE[i]=0;
       COMPUTER_PATH_WAIT[i]=0;
-     }
+    }
 }
 
 /*------------------------------------------------------------------*/
 static void random_free_xy_different_team (int *x, int *y, int team)
 {
- int i,found=0,foundable=0,foundable_human=0;
- int cpu_or_human[NB_TEAMS]={0,0,0,0,0,0};
+  int i,found=0,foundable=0,foundable_human=0;
+  int control_type[NB_TEAMS];
+  int random_limit;
 
- for (i=0;i<NB_TEAMS;++i)
-     if (CURRENT_CURSOR[i].cpu_or_human
-        && CURRENT_CURSOR[i].active)
-        cpu_or_human[CURRENT_CURSOR[i].team]=1;
+  for (i=0;i<NB_TEAMS;++i)
+    {
+      control_type[i]=CONFIG_CONTROL_TYPE_OFF;
+    }
 
- for (i=0;i<CURRENT_ARMY_SIZE && !foundable_human;++i)
-     {
+  for (i=0;i<NB_TEAMS;++i)
+    {
+      if (CURRENT_CURSOR[i].control_type == CONFIG_CONTROL_TYPE_HUMAN
+	  && CURRENT_CURSOR[i].active)
+	{
+	  control_type[CURRENT_CURSOR[i].team]=CURRENT_CURSOR[i].control_type;
+	}
+    }
+
+  for (i=0;i<CURRENT_ARMY_SIZE && !foundable_human;++i)
+    {
       foundable|=CURRENT_ARMY[i].team!=team;
-      foundable_human|=!cpu_or_human[(int)(CURRENT_ARMY[i].team)];
-     }
+      foundable_human|=(control_type[(int)(CURRENT_ARMY[i].team)] == 
+			CONFIG_CONTROL_TYPE_HUMAN);
+    }
 
- if (foundable_human)
-   while (!found)
-      {
-       i=rand()%CURRENT_ARMY_SIZE;
-       found=!cpu_or_human[(int)(CURRENT_ARMY[i].team)];
-      }
+  if (foundable_human)
+    {
+      random_limit=0;
 
- if (foundable)
-   while (!found)
-      {
-       i=rand()%CURRENT_ARMY_SIZE;
-       found=(CURRENT_ARMY[i].team!=team);
-      }
+      while ((!found) && random_limit<LW_AUTOPLAY_RANDOM_LIMIT)
+	{
+	  i=rand()%CURRENT_ARMY_SIZE;
+	  found=(control_type[(int)(CURRENT_ARMY[i].team)] ==
+		 CONFIG_CONTROL_TYPE_HUMAN);
+	  random_limit++;
+	}
+    }
 
- if (!found)
+  if (foundable)
+    {
+      random_limit=0;
+      
+      while ((!found) && random_limit<LW_AUTOPLAY_RANDOM_LIMIT)
+	{
+	  i=rand()%CURRENT_ARMY_SIZE;
+	  found=(CURRENT_ARMY[i].team!=team);
+	  random_limit++;
+	}
+    }
+
+  if (!found)
     i=rand()%CURRENT_ARMY_SIZE;
 
- (*x)=CURRENT_ARMY[i].x;
- (*y)=CURRENT_ARMY[i].y;
+  (*x)=CURRENT_ARMY[i].x;
+  (*y)=CURRENT_ARMY[i].y;
 }
 
 /*------------------------------------------------------------------*/
 char get_computer_next_move  ( int cursor)
 {
- FIGHTER *f;
- char key_info;
- int x,y;
- int meme_equipe,team;
+  FIGHTER *f;
+  char key_info;
+  int x,y;
+  int meme_equipe,team;
 
- if (COMPUTER_PATH_SIZE[cursor]>0)
+  if (COMPUTER_PATH_SIZE[cursor]>0)
     {
-     key_info=COMPUTER_PATH_KEYS [cursor]
-                                 [--COMPUTER_PATH_SIZE[cursor]];
+      key_info=COMPUTER_PATH_KEYS [cursor]
+	[--COMPUTER_PATH_SIZE[cursor]];
     }
- else
-     {
+  else
+    {
       key_info=0;
       team=CURRENT_CURSOR[cursor].team;
       f=CURRENT_AREA [CURRENT_CURSOR[cursor].y*CURRENT_AREA_W
-                     +CURRENT_CURSOR[cursor].x].fighter;
+		      +CURRENT_CURSOR[cursor].x].fighter;
       if (f)
-         meme_equipe=(f->team==team);
+	meme_equipe=(f->team==team);
       else
-          meme_equipe=1;
+	meme_equipe=1;
       if ((--COMPUTER_PATH_WAIT[cursor])<0 || meme_equipe)
-         {
+	{
           random_free_xy_different_team (&x,&y,team);
           calculate_computer_path (x,y,cursor);
-         }
-     }
+	}
+    }
 
- return key_info;
+  return key_info;
 }
 
