@@ -116,6 +116,7 @@
 #define LABEL_SERVER_PORT "SERVER_PORT"
 #define LABEL_ASM_ALGORITHM "ASM_ALGORITHM"
 #define LABEL_PASSWORD "PASSWORD"
+#define LABEL_MIN_MAP_RES "MIN_MAP_RES"
 
 int CONFIG_GFX_GAME;
 int CONFIG_GFX_MENU;
@@ -160,6 +161,7 @@ char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
 int CONFIG_SERVER_PORT;
 int CONFIG_ASM_ALGORITHM;
 char CONFIG_PASSWORD[PASSWORD_SIZE+1];
+int CONFIG_MIN_MAP_RES;
 
 LW_NETCONF LW_CONFIG_CURRENT_RULES;
 
@@ -168,9 +170,11 @@ LW_NETCONF LW_CONFIG_CURRENT_RULES;
 /*==================================================================*/
 
 int DISPLAY_DELAY_MIN[9]={0, 10,15,20,25,
-			  33,50,66,100};
+			  33,40,55,100};
 int LOGIC_DELAY_MIN[9]={0, 1, 2, 5, 10,
 			15, 20, 33, 50};
+int MIN_MAP_RES_W[9]={0, 80,120,160,200,240,320,480,640};
+int MIN_MAP_RES_H[9]={0, 60, 90,120,150,180,240,360,480};
 
 /*------------------------------------------------------------------*/
 /* fonctions de gestion des parametres de configuration             */
@@ -205,11 +209,6 @@ void load_default_options (void)
   CONFIG_WAVE_SPEED[3]=9; 
  
   CONFIG_BRIGHTNESS=8;
-  CONFIG_CURSOR_INCREASE_SPEED=0;
-  CONFIG_FIGHTER_ATTACK=8;
-  CONFIG_FIGHTER_DEFENSE=8;
-  CONFIG_FIGHTER_NEW_HEALTH=8;
-  CONFIG_NUMBER_INFLUENCE=8;
   CONFIG_SFX_VOLUME=12;
   CONFIG_CLICK_VOLUME=8;
   CONFIG_WATER_VOLUME_MENU=6;
@@ -218,7 +217,6 @@ void load_default_options (void)
   CONFIG_LEVEL_MAP=0;
   CONFIG_LEVEL_FG=135;
   CONFIG_LEVEL_BG=131;
-  CONFIG_FIGHTER_NUMBER=16;
  
   CONFIG_KEY_UP[0]= KEY_UP;
   CONFIG_KEY_DOWN[0]= KEY_DOWN;
@@ -268,11 +266,9 @@ void load_default_options (void)
   CONFIG_CONTROL_TYPE[5]=CONFIG_CONTROL_TYPE_CPU;
   strcpy(CONFIG_PLAYER_NAME[5],"Attila");
 
-  CONFIG_GAME_TIME=8;
   CONFIG_INFO_BAR=1;
   CONFIG_MOUSE_GAP=4;
   CONFIG_JOYSTICK_ON=1;
-  CONFIG_CPU_ADVANTAGE=0;
   CONFIG_PAGE_FLIP=0;
   CONFIG_LANGUAGE=LW_LANG_LANGUAGE_AUTO;
   CONFIG_WAVE_ON=1;
@@ -283,9 +279,24 @@ void load_default_options (void)
   strcpy(CONFIG_SERVER_ADDRESS,LW_SERVER_DEFAULT_ADDRESS);
   CONFIG_SERVER_PORT=LW_SERVER_DEFAULT_PORT;
 
-  CONFIG_ASM_ALGORITHM=1;
-
   strcpy(CONFIG_PASSWORD,"toto");
+
+  load_default_rules();
+}
+
+/*------------------------------------------------------------------*/
+void load_default_rules (void)
+{
+  CONFIG_CURSOR_INCREASE_SPEED=0;
+  CONFIG_FIGHTER_ATTACK=8;
+  CONFIG_FIGHTER_DEFENSE=8;
+  CONFIG_FIGHTER_NEW_HEALTH=8;
+  CONFIG_NUMBER_INFLUENCE=8;
+  CONFIG_FIGHTER_NUMBER=16;
+  CONFIG_GAME_TIME=8;
+  CONFIG_CPU_ADVANTAGE=0;
+  CONFIG_ASM_ALGORITHM=1;
+  CONFIG_MIN_MAP_RES=4;
 }
 
 /*------------------------------------------------------------------*/
@@ -363,6 +374,8 @@ static int load_disk_options (void)
 
       strncpy(CONFIG_PASSWORD,get_config_string(LABEL_MAIN,LABEL_PASSWORD,CONFIG_PASSWORD),sizeof(CONFIG_PASSWORD));
       CONFIG_PASSWORD[sizeof(CONFIG_PASSWORD)-1]='\0';
+
+      CONFIG_MIN_MAP_RES=get_config_int(LABEL_MAIN,LABEL_MIN_MAP_RES,CONFIG_MIN_MAP_RES);
       return 1;
     }
   else
@@ -458,6 +471,8 @@ int save_config_options (void)
 
   set_config_string(LABEL_MAIN,LABEL_PASSWORD,CONFIG_PASSWORD);
 
+  set_config_int(LABEL_MAIN,LABEL_MIN_MAP_RES,CONFIG_MIN_MAP_RES);
+
   return 0;
 }
 
@@ -490,4 +505,5 @@ void lw_config_set_current_rules_to_default (void)
   config->game_time=CONFIG_GAME_TIME;
   config->cpu_advantage=CONFIG_CPU_ADVANTAGE;
   config->asm_algorithm=CONFIG_ASM_ALGORITHM && STARTUP_ASM;
+  config->min_map_res=CONFIG_MIN_MAP_RES;
 }
