@@ -111,6 +111,7 @@ extern char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
 extern int CONFIG_SERVER_PORT;
 extern int CONFIG_ASM_ALGORITHM;
 extern char CONFIG_PASSWORD[PASSWORD_SIZE+1];
+extern int CONFIG_MIN_MAP_RES;
 
 #define CONFIG_CONTROL_TYPE_OFF    0
 #define CONFIG_CONTROL_TYPE_HUMAN  1
@@ -124,12 +125,15 @@ extern LW_NETCONF LW_CONFIG_CURRENT_RULES;
 
 extern int DISPLAY_DELAY_MIN[9];
 extern int LOGIC_DELAY_MIN[9];
+extern int MIN_MAP_RES_W[9];
+extern int MIN_MAP_RES_H[9];
 
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
 void load_default_options (void);
+void load_default_rules (void);
 int load_config_options (void);
 int save_config_options (void);
 void check_config_range (void);
