@@ -60,6 +60,7 @@
 #include "lang.h"
 #include "exit.h"
 #include "keyboard.h"
+#include "capture.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -290,6 +291,7 @@ int my_update_dialog (DIALOG_PLAYER *player)
   int result;
 
   result=update_dialog(player);
+  lw_capture_dump_menu();
   my_exit_poll();
 
   yield_timeslice();
