@@ -190,5 +190,12 @@ int error_bad_password(void)
 			 (LW_LANG_STRING_ERROR_BADPASSWORD)));
 }
 
+/*------------------------------------------------------------------*/
+int error_bad_config_range(void)
+{
+  return (standard_error(lw_lang_string
+			 (LW_LANG_STRING_ERROR_BADCONFIGRANGE)));
+}
+
 
 
