@@ -218,7 +218,11 @@ void my_exit_close_button (void)
 /*------------------------------------------------------------------*/
 void my_exit_poll()
 {
-  if (LW_EXIT_FORCE_SHUTDOWN)
+  /*
+   * We exit if the close button has been clicked or
+   * F10 has been pressed
+   */
+  if (LW_EXIT_FORCE_SHUTDOWN || key[KEY_F10])
     {
       my_exit(EXIT_CODE_OK);
     }
