@@ -64,13 +64,15 @@
 #define EXIT_CODE_MEM_TROUBLE 2
 #define EXIT_CODE_BIG_DATA 3
 #define EXIT_CODE_LOAD_FAIL 4
-#define EXIT_CODE_INTEGRITY 5
-#define EXIT_CODE_CUSTOM_FAIL 6
+#define EXIT_CODE_CUSTOM_FAIL 5
+#define EXIT_CODE_GRAPHICS_FAIL 6
 
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
+void my_exit_close_button (void);
+void my_exit_poll ();
 void my_exit (int code);
 
 #endif
