@@ -75,41 +75,42 @@
 
 #define NB_SENS_MOVE 2
 #define NB_TRY_MOVE 5
+#define NB_LOCAL_DIRS 16
 
-static int LOCAL_DIR[24];
+static int LOCAL_DIR[NB_LOCAL_DIRS*2];
 
 static int FIGHTER_MOVE_DIR[NB_SENS_MOVE][NB_DIRS][NB_TRY_MOVE]=
-{{{ DIR_NNE, DIR_NE,  DIR_NW,  DIR_ENE, DIR_WNW},
-  { DIR_NE,  DIR_ENE, DIR_NNE, DIR_SE,  DIR_NW},
-  { DIR_ENE, DIR_NE,  DIR_SE,  DIR_NNE, DIR_SSE},
-  { DIR_ESE, DIR_SE,  DIR_NE,  DIR_SSE, DIR_NNE},
-  { DIR_SE,  DIR_SSE, DIR_ESE, DIR_SW,  DIR_NE},
-  { DIR_SSE, DIR_SE,  DIR_SW,  DIR_ESE, DIR_WSW},
-  { DIR_SSW, DIR_SW,  DIR_SE,  DIR_WSW, DIR_ESE},
-  { DIR_SW,  DIR_WSW, DIR_SSW, DIR_NW,  DIR_SE},
-  { DIR_WSW, DIR_SW,  DIR_NW,  DIR_SSW, DIR_NNW},
-  { DIR_WNW, DIR_NW,  DIR_SW,  DIR_NNW, DIR_SSE},
-  { DIR_NW,  DIR_NNW, DIR_WNW, DIR_NE,  DIR_SW},
-  { DIR_NNW, DIR_NW,  DIR_NE,  DIR_WNW, DIR_ENE}},
+  {{{ DIR_NNE, DIR_NE,  DIR_NW,  DIR_ENE, DIR_WNW},
+    { DIR_NE,  DIR_ENE, DIR_NNE, DIR_SE,  DIR_NW},
+    { DIR_ENE, DIR_NE,  DIR_SE,  DIR_NNE, DIR_SSE},
+    { DIR_ESE, DIR_SE,  DIR_NE,  DIR_SSE, DIR_NNE},
+    { DIR_SE,  DIR_SSE, DIR_ESE, DIR_SW,  DIR_NE},
+    { DIR_SSE, DIR_SE,  DIR_SW,  DIR_ESE, DIR_WSW},
+    { DIR_SSW, DIR_SW,  DIR_SE,  DIR_WSW, DIR_ESE},
+    { DIR_SW,  DIR_WSW, DIR_SSW, DIR_NW,  DIR_SE},
+    { DIR_WSW, DIR_SW,  DIR_NW,  DIR_SSW, DIR_NNW},
+    { DIR_WNW, DIR_NW,  DIR_SW,  DIR_NNW, DIR_SSE},
+    { DIR_NW,  DIR_NNW, DIR_WNW, DIR_NE,  DIR_SW},
+    { DIR_NNW, DIR_NW,  DIR_NE,  DIR_WNW, DIR_ENE}},
 
- {{ DIR_NNE, DIR_NE,  DIR_NW,  DIR_ENE, DIR_WNW},
-  { DIR_NE,  DIR_NNE, DIR_ENE, DIR_NW,  DIR_SE},
-  { DIR_ENE, DIR_NE,  DIR_SE,  DIR_NNE, DIR_SSE},
-  { DIR_ESE, DIR_SE,  DIR_NE,  DIR_SSE, DIR_NNE},
-  { DIR_SE,  DIR_ESE, DIR_SSE, DIR_NE,  DIR_SW},
-  { DIR_SSE, DIR_SE,  DIR_SW,  DIR_ESE, DIR_WSW},
-  { DIR_SSW, DIR_SW,  DIR_SE,  DIR_WSW, DIR_ESE},
-  { DIR_SW,  DIR_SSW, DIR_WSW, DIR_SE,  DIR_NW},
-  { DIR_WSW, DIR_SW,  DIR_NW,  DIR_SSW, DIR_NNW},
-  { DIR_WNW, DIR_NW,  DIR_SW,  DIR_NNW, DIR_SSE},
-  { DIR_NW,  DIR_WNW, DIR_NNW, DIR_SW,  DIR_NE},
-  { DIR_NNW, DIR_NW,  DIR_NE,  DIR_WNW, DIR_ENE}}};
+   {{ DIR_NNE, DIR_NE,  DIR_NW,  DIR_ENE, DIR_WNW},
+    { DIR_NE,  DIR_NNE, DIR_ENE, DIR_NW,  DIR_SE},
+    { DIR_ENE, DIR_NE,  DIR_SE,  DIR_NNE, DIR_SSE},
+    { DIR_ESE, DIR_SE,  DIR_NE,  DIR_SSE, DIR_NNE},
+    { DIR_SE,  DIR_ESE, DIR_SSE, DIR_NE,  DIR_SW},
+    { DIR_SSE, DIR_SE,  DIR_SW,  DIR_ESE, DIR_WSW},
+    { DIR_SSW, DIR_SW,  DIR_SE,  DIR_WSW, DIR_ESE},
+    { DIR_SW,  DIR_SSW, DIR_WSW, DIR_SE,  DIR_NW},
+    { DIR_WSW, DIR_SW,  DIR_NW,  DIR_SSW, DIR_NNW},
+    { DIR_WNW, DIR_NW,  DIR_SW,  DIR_NNW, DIR_SSE},
+    { DIR_NW,  DIR_WNW, DIR_NNW, DIR_SW,  DIR_NE},
+    { DIR_NNW, DIR_NW,  DIR_NE,  DIR_WNW, DIR_ENE}}};
 
 static int FIGHTER_MOVE_X_REF[NB_DIRS]=
-{ 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0};
+  { 0, 1, 1, 1, 1, 0, 0, -1, -1, -1, -1, 0};
 
 static int FIGHTER_MOVE_Y_REF[NB_DIRS]=
-{ -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1,-1};
+  { -1, -1, 0, 0, 1, 1, 1, 1, 0, 0, -1,-1};
 
 static int FIGHTER_MOVE_OFFSET_ASM[NB_SENS_MOVE][NB_DIRS*NB_TRY_MOVE];
 static int FIGHTER_MOVE_XY_ASM[NB_SENS_MOVE][NB_DIRS*NB_TRY_MOVE];
@@ -160,41 +161,52 @@ void init_move_fighters(void)
           if (FIGHTER_MOVE_Y[k][i][j]==-1)
 	    FIGHTER_MOVE_OFFSET[k][i][j]-=CURRENT_AREA_W;
 
-	  FIGHTER_MOVE_OFFSET_ASM[k][i*5+j]=
+	  FIGHTER_MOVE_OFFSET_ASM[k][i*NB_TRY_MOVE+j]=
 	    FIGHTER_MOVE_OFFSET[k][i][j];
-          FIGHTER_MOVE_XY_ASM[k][i*5+j]=
-	    FIGHTER_MOVE_Y[k][i][j]*65536+
+          FIGHTER_MOVE_XY_ASM[k][i*NB_TRY_MOVE+j]=
+	    FIGHTER_MOVE_Y[k][i][j]*65536 +
 	    FIGHTER_MOVE_X[k][i][j];
 	}
 
   for (i=0;i<CURRENT_ARMY_SIZE;++i)
     disp_fighter (CURRENT_ARMY+i);
 
-  for (i=1;i<12;++i)
-    for (j=0;j<2;++j)
-      {
-	k=-1;
-	switch (i)
-	  {
-	  case 1: k=j ? DIR_NNW : DIR_NNE;
-	    break;
-	  case 3: k=DIR_NE;
-	    break;
-	  case 2: k=j ? DIR_ENE : DIR_ESE;
-	    break;
-	  case 6: k=DIR_SE;
-	    break;
-	  case 4: k=j ? DIR_SSE : DIR_SSW;
-	    break;
-	  case 12:k=DIR_SW;
-	    break;
-	  case 8: k=j ? DIR_WSW : DIR_WNW;
-	    break;
-	  case 9: k=DIR_NW;
-	    break;
-	  }
+  /*
+   * note:
+   * NB_LOCAL_DIRS is 16 but it's true that 12 is enough.
+   * However, I find it safer to reserve 16 slots, since
+   * this way all the combinations of 1,2,4 and 8 can
+   * be handled correctly - even if some are impossible.
+   * And it has the advantage to avoid confusion with
+   * the 12 directions represented by NB_DIRS.
+   */
+  for (i=1;i<=NB_LOCAL_DIRS;++i)
+    {
+      for (j=0;j<2;++j)
+	{
+	  k=-1;
+	  switch (i)
+	    {
+	    case 1: k=j ? DIR_NNW : DIR_NNE;
+	      break;
+	    case 3: k=DIR_NE;
+	      break;
+	    case 2: k=j ? DIR_ENE : DIR_ESE;
+	      break;
+	    case 6: k=DIR_SE;
+	      break;
+	    case 4: k=j ? DIR_SSE : DIR_SSW;
+	      break;
+	    case 12:k=DIR_SW;
+	      break;
+	    case 8: k=j ? DIR_WSW : DIR_WNW;
+	      break;
+	    case 9: k=DIR_NW;
+	      break;
+	    }
 	LOCAL_DIR[(i-1)*2+j]=k;
-      }
+	}
+    }
 }
 
 /*------------------------------------------------------------------*/
@@ -371,7 +383,7 @@ void move_fighters (void)
 			 temp);
   else
 #else
-  temp=0;
+    temp=0;
 #endif
   for (i=0;i<CURRENT_ARMY_SIZE;++i)
     {
