@@ -86,6 +86,7 @@
 #include "lang.h"
 #include "exit.h"
 #include "capture.h"
+#include "startup.h"
 
 /*==================================================================*/
 /* definitions de constantes                                        */
@@ -244,6 +245,12 @@ int check_loose_team (void)
  */
 char  *init_game (void)
 {
+  int i;
+  int big_data;
+  int max_mem_reached=0;
+  int last_try=0;
+  int ok=0;
+
   /*
    * this string will be used to display error messages in case
    * something goes wrong. as long as message is not NULL it
@@ -258,10 +265,13 @@ char  *init_game (void)
    * no fighters drawn on it)
    */
   if (!message &&
-      (CURRENT_AREA_BACK=create_textured_map (CONFIG_LEVEL_MAP,
-                                              CONFIG_LEVEL_FG,
-                                              CONFIG_LEVEL_BG,
-					      LW_NETWORK_ON))
+      (CURRENT_AREA_BACK=create_textured_map 
+       (CONFIG_LEVEL_MAP,
+	CONFIG_LEVEL_FG,
+	CONFIG_LEVEL_BG,
+	LW_NETWORK_ON,
+	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res]))
       ==NULL)
     message=lw_lang_string(LW_LANG_STRING_GAME_BACKMEMFAIL);
 
@@ -271,30 +281,94 @@ char  *init_game (void)
    * will be drawn on it
    */
   if (!message &&
-      (CURRENT_AREA_DISP=create_textured_map (CONFIG_LEVEL_MAP,
-                                              CONFIG_LEVEL_FG,
-                                              CONFIG_LEVEL_BG,
-					      LW_NETWORK_ON))
+      (CURRENT_AREA_DISP=create_textured_map 
+       (CONFIG_LEVEL_MAP,
+	CONFIG_LEVEL_FG,
+	CONFIG_LEVEL_BG,
+	LW_NETWORK_ON,
+	MIN_MAP_RES_W[LW_CONFIG_CURRENT_RULES.min_map_res],
+	MIN_MAP_RES_H[LW_CONFIG_CURRENT_RULES.min_map_res]))
       ==NULL)
     message=lw_lang_string(LW_LANG_STRING_GAME_DISPMEMFAIL);
 
-  /*
-   * creation of the mesh, see mesh.c for details
-   */
-  if (!message && create_mesh())
-    message=lw_lang_string(LW_LANG_STRING_GAME_MESHMEMFAIL);
+  if (!message)
+    {
+      for (i=0;!max_mem_reached && !ok;++i)
+	{
+	  message=NULL;
+	  reset_big_data();
 
-  /*
-   * creation of the game area, see area.c for details
-   */
-  if (!message && create_game_area())
-    message=lw_lang_string(LW_LANG_STRING_GAME_AREAMEMFAIL);
+	  /*
+	   * creation of the mesh, see mesh.c for details
+	   */
+	  if (!message && create_mesh())
+	    message=lw_lang_string(LW_LANG_STRING_GAME_MESHMEMFAIL);
+      
+	  /*
+	   * creation of the game area, see area.c for details
+	   */
+	  if (!message && create_game_area())
+	    message=lw_lang_string(LW_LANG_STRING_GAME_AREAMEMFAIL);
+	  
+	  /*
+	   * creation of the armies, see army.c for details
+	   */
+	  if (!message && create_army())
+	    message=lw_lang_string(LW_LANG_STRING_GAME_ARMYMEMFAIL);
 
-  /*
-   * creation of the armies, see army.c for details
-   */
-  if (!message && create_army())
-    message=lw_lang_string(LW_LANG_STRING_GAME_ARMYMEMFAIL);
+	  if (message)
+	    {
+	      /*
+	       * There's an error.
+	       */
+	      if (last_try)
+		{
+		  /*
+		   * OK, last time we allocated memory, we couldn't
+		   * allocate all we wanted to, and this is not
+		   * enough -> we give up...
+		   */
+		  max_mem_reached=0;
+		}
+	      else
+		{
+		  /*
+		   * We increase the amount of allocated memory
+		   */
+		  STARTUP_BIG_DATA+=LW_STARTUP_MEM_STEP;
+		  if (STARTUP_BIG_DATA>LW_STARTUP_MEM_MAX)
+		    {
+		      last_try=1;
+		      STARTUP_BIG_DATA=LW_STARTUP_MEM_MAX;
+		    }
+		  big_data=STARTUP_BIG_DATA;
+		  if (malloc_big_data())
+		    {
+		      if (STARTUP_BIG_DATA != big_data)
+			{
+			  /*
+			   * not all the memory could be
+			   * allocated, we consider this is
+			   * the last try.
+			   */
+			  last_try=1;
+			}
+		    }
+		  else
+		    {
+		      /*
+		       * memory allocation failed...
+		       */
+		      max_mem_reached=1;
+		    }
+		}
+	    }
+	  else
+	    {
+	      ok=1;
+	    }
+	}
+    }
 
   /*
    * what to do nothing failed (play!)
