@@ -145,7 +145,7 @@ void spread_single_gradient (void)
     case DIR_SSE :
     case DIR_SSW :
     case DIR_SW  :
-      pos=CURRENT_MESH+1;
+      pos=CURRENT_MESH;
       last=CURRENT_MESH+CURRENT_MESH_SIZE;
 #ifdef ASM
       if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
@@ -196,7 +196,7 @@ void spread_single_gradient (void)
     case DIR_NNE :
     case DIR_NE  :
       pos=CURRENT_MESH+CURRENT_MESH_SIZE-1;
-      last=CURRENT_MESH;
+      last=CURRENT_MESH-1;
 #ifdef ASM
       if (STARTUP_ASM && LW_CONFIG_CURRENT_RULES.asm_algorithm)
 	switch (PLAYING_TEAMS)
