@@ -155,7 +155,8 @@ int lw_lang_auto()
 	 * We try and check if LANG is set to "FR..." to enable French
 	 * support.
 	 */
-	if (strncmp("FR",env_lang,2)==0)
+	if (strncmp(env_lang,"FR",2) == 0 || 
+	    strncmp(env_lang,"fr",2) == 0)
 	  { 
 	    language=LW_LANG_LANGUAGE_FRANCAIS;
 	  }
