@@ -185,10 +185,13 @@ static void display_chosen_level (void)
   set_fg_texture_palette (CONFIG_LEVEL_FG);
   my_set_palette ();
 
-  pour_voir=create_textured_map (CONFIG_LEVEL_MAP,
-				 CONFIG_LEVEL_FG,
-				 CONFIG_LEVEL_BG,
-				 0);
+  pour_voir=create_textured_map 
+    (CONFIG_LEVEL_MAP,
+     CONFIG_LEVEL_FG,
+     CONFIG_LEVEL_BG,
+     0,
+     MIN_MAP_RES_W[CONFIG_MIN_MAP_RES],
+     MIN_MAP_RES_H[CONFIG_MIN_MAP_RES]);
   if (pour_voir)
     {
       max_w=menu_real_x(MENU_W_SAMPLE);
@@ -279,7 +282,9 @@ static void update_choose_map (DIALOG *d)
     d[6].d2=0;
   my_slider_proc (MSG_DRAW,d+6,0);
 
-  get_map_res(CONFIG_LEVEL_MAP,&res_w,&res_h,0);
+  get_map_res(CONFIG_LEVEL_MAP,&res_w,&res_h,0,
+	      MIN_MAP_RES_W[CONFIG_MIN_MAP_RES],
+	      MIN_MAP_RES_H[CONFIG_MIN_MAP_RES]);
   sprintf(res_buffer,"%dx%d",res_w,res_h);
   d[16].dp=res_buffer;
   my_textbox_proc (MSG_DRAW,d+16,0);
