@@ -68,9 +68,12 @@
 /*==================================================================*/
 
 void *archive_raw_map (const char *filename);
-BITMAP *create_bicolor_map (int num, int fg, int bg, int network);
-BITMAP *create_textured_map (int num, int fg, int bg, int network);
+BITMAP *create_bicolor_map (int num, int fg, int bg, 
+			    int network, int min_w, int min_h);
+BITMAP *create_textured_map (int num, int fg, int bg, 
+			     int network, int min_w, int min_h);
 char *get_map_readable_name (int num, int network);
-void get_map_res (int num,int *w,int *h, int network);
+void get_map_res (int num,int *w,int *h, 
+		  int network, int min_w, int min_h);
 
 #endif
