@@ -72,6 +72,8 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+#define LW_MOVE_SIDE_LIMIT 10
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -311,25 +313,75 @@ static void move_cursor (int indice)
       /*
        * we first try to move in the direction we have calculated
        */
-      moved=move_if_free (&(CURRENT_CURSOR[indice]).x,
-			  &(CURRENT_CURSOR[indice]).y,
+      moved=move_if_free (&(CURRENT_CURSOR[indice].x),
+			  &(CURRENT_CURSOR[indice].y),
 			  dir);
       /*
        * if it did not work, we try another direction
        * for instance if the direction was NORTH WEST we try WEST
        */
       if (!moved)
-        moved=move_if_free (&(CURRENT_CURSOR[indice]).x,
-                            &(CURRENT_CURSOR[indice]).y,
+        moved=move_if_free (&(CURRENT_CURSOR[indice].x),
+                            &(CURRENT_CURSOR[indice].y),
                             dir-1);
       /*
        * if it did not work, we try another direction
        * for instance if the direction was NORTH WEST we try NORTH
        */
       if (!moved)
-        moved=move_if_free (&(CURRENT_CURSOR[indice]).x,
-                            &(CURRENT_CURSOR[indice]).y,
+        moved=move_if_free (&(CURRENT_CURSOR[indice].x),
+                            &(CURRENT_CURSOR[indice].y),
                             dir+1);
+      /*
+       * The following code allows the cursor to really "slip" on walls.
+       * Not very elegant, but it works 8-)
+       */
+      if (!moved)
+	{
+	  int xa1,ya1;
+	  int xb1,yb1;
+	  int xa2,ya2;
+	  int xb2,yb2;
+	  int i=0;
+
+	  xa1=xb1=CURRENT_CURSOR[indice].x;
+	  ya1=yb1=CURRENT_CURSOR[indice].y;
+	  
+	  while (!moved && i<LW_MOVE_SIDE_LIMIT)
+	    {
+	      if (move_if_free(&xa1,&ya1,dir-2))
+		{
+		  xa2=xa1;
+		  ya2=ya1;
+		  if (move_if_free(&xa2,&ya2,dir-1))
+		    {
+		      /*
+		       * Normally moved should be true after this
+		       */
+		      moved=move_if_free(&(CURRENT_CURSOR[indice].x),
+					 &(CURRENT_CURSOR[indice].y),
+					 dir-2);
+		    }
+		}
+
+	      if (move_if_free(&xb1,&yb1,dir+2))
+		{
+		  xb2=xb1;
+		  yb2=yb1;
+		  if (move_if_free(&xb2,&yb2,dir+1))
+		    {
+		      /*
+		       * Normally moved should be true after this
+		       */
+		      moved=move_if_free(&(CURRENT_CURSOR[indice].x),
+					 &(CURRENT_CURSOR[indice].y),
+					 dir+2);
+		    }
+		}
+
+	      i++;
+	    }
+	}
     }
   /*
    * now this is quite a subtle line
