@@ -72,6 +72,7 @@ typedef struct
   int game_time;
   int cpu_advantage;
   int asm_algorithm;
+  int min_map_res;
 } LW_NETCONF;
 
 /*==================================================================*/
@@ -81,6 +82,7 @@ typedef struct
 int lw_netconf_send(int sock,LW_NETCONF *config);
 int lw_netconf_recv(int sock,LW_NETCONF *config);
 int lw_netconf_check(LW_NETCONF *config);
+void lw_netconf_print(LW_NETCONF *config);
 
 #endif
 
