@@ -58,6 +58,7 @@
 #include "netmap.h"
 #include "log.h"
 #include "sock2gen.h"
+#include "map.h"
 
 /*==================================================================*/
 /* constants                                                        */
@@ -93,25 +94,31 @@ int lw_netmap_send(int sock,void *netmap)
   char_ptr=(char *) netmap;
   if (lw_sock_send_buffer(sock,char_ptr,8))
     {
-      int_ptr=(int *) char_ptr;
-      size=int_ptr[0];
-
-      result=1;
-      sent=0;
-      while (sent<size && result)
+      if (lw_sock_send_buffer(sock,char_ptr+8,LW_MAP_READABLE_NAME_SIZE))
 	{
-	  to_send=size-sent;
-	  if (to_send>LW_NETMAP_CHUNK_SIZE)
+	  int_ptr=(int *) char_ptr;
+	  size=int_ptr[0];
+	  
+	  result=1;
+	  sent=0;
+	  while (sent<size && result)
 	    {
-	      to_send=LW_NETMAP_CHUNK_SIZE;
-	    }
-	  if (lw_sock_send_buffer(sock,char_ptr+8+sent,to_send))
-	    {
-	      sent+=to_send;
-	    }
-	  else
-	    {
-	      result=0;
+	      to_send=size-sent;
+	      if (to_send>LW_NETMAP_CHUNK_SIZE)
+		{
+		  to_send=LW_NETMAP_CHUNK_SIZE;
+		}
+	      if (lw_sock_send_buffer
+		  (sock,
+		   char_ptr+8+LW_MAP_READABLE_NAME_SIZE+sent,
+		   to_send))
+		{
+		  sent+=to_send;
+		}
+	      else
+		{
+		  result=0;
+		}
 	    }
 	}
     }
@@ -126,7 +133,7 @@ int lw_netmap_send(int sock,void *netmap)
 int lw_netmap_recv(int sock,void **netmap)
 {
   int result=0;
-  char buffer[8];
+  char buffer[8+LW_MAP_READABLE_NAME_SIZE];
   int size;
   short w,h;
   int *int_ptr;
@@ -140,37 +147,50 @@ int lw_netmap_recv(int sock,void **netmap)
     {
       free(char_ptr);
     }
+  char_ptr=NULL;
 
   if (lw_sock_recv_buffer(sock,buffer,8))
     {
-      int_ptr=(int *) buffer;
-      short_ptr=(short *) buffer;
-      size=int_ptr[0];
-      w=short_ptr[2];
-      h=short_ptr[3];
-
-      char_ptr=malloc(size+8);
-      if (char_ptr!=NULL)
+      if (lw_sock_recv_buffer(sock,buffer+8,LW_MAP_READABLE_NAME_SIZE))
 	{
-	  memcpy(char_ptr,buffer,8);
-
-	  result=1;
-	  received=0;
-	  while (received<size && result)
-	    {
-	      to_receive=size-received;
-	      if (to_receive>LW_NETMAP_CHUNK_SIZE)
+	  int_ptr=(int *) buffer;
+	  short_ptr=(short *) buffer;
+	  size=int_ptr[0];
+	  w=short_ptr[2];
+	  h=short_ptr[3];
+	  
+	  /*
+	   * A map under 3 bytes is reasonably not a "real" map...
+	   */
+	  if (size>=10)
+	    {	 
+	      char_ptr=malloc(size+8+LW_MAP_READABLE_NAME_SIZE);
+	      if (char_ptr!=NULL)
 		{
-		  to_receive=LW_NETMAP_CHUNK_SIZE;
-		}
-
-	      if (lw_sock_recv_buffer(sock,char_ptr+8+received,to_receive))
-		{
-		  received+=to_receive;
-		}
-	      else
-		{
-		  result=0;
+		  memcpy(char_ptr,buffer,8+LW_MAP_READABLE_NAME_SIZE);
+		  
+		  result=1;
+		  received=0;
+		  while (received<size && result)
+		    {
+		      to_receive=size-received;
+		      if (to_receive>LW_NETMAP_CHUNK_SIZE)
+			{
+			  to_receive=LW_NETMAP_CHUNK_SIZE;
+			}
+		      
+		      if (lw_sock_recv_buffer
+			  (sock,
+			   char_ptr+8+LW_MAP_READABLE_NAME_SIZE+received,
+			   to_receive))
+			{
+			  received+=to_receive;
+			}
+		      else
+			{
+			  result=0;
+			}
+		    }
 		}
 	    }
 	}
