@@ -452,6 +452,15 @@ static int connect_on_server_finish(int sock)
 	  error_network_problem();
 	}
     }
+
+  if (result==1)
+    {
+      if (!lw_netconf_check(&LW_CONFIG_CURRENT_RULES))
+	{
+	  result=0;
+	  error_bad_config_range();
+	}
+    }
   
   if (result==1)
     {
