@@ -71,6 +71,7 @@
 #include "language.h"
 #include "controls.h"
 #include "lang.h"
+#include "gfxmode.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -84,7 +85,11 @@
 int options (void)
 {
   DIALOG d[12];
+  DIALOG_PLAYER *dp;
   int i,choix=4,retour=0;
+  int old_gfx_menu;
+  int old_fullscreen;
+  int gfxmode_change=0;
 
   memset(d,0,sizeof(d));
 
@@ -104,7 +109,29 @@ int options (void)
       d[10].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_DEFAULT);
       d[11].proc=0;
 
-      choix=my_do_dialog (d,choix);
+      old_gfx_menu=CONFIG_GFX_MENU;
+      old_fullscreen=CONFIG_FULLSCREEN;
+
+      display_back_image();
+      if (gfxmode_change)
+	{
+	  gfxmode_change=0;
+	  display_back_image ();
+	  dp=my_init_dialog (d,choix);
+	  my_fade_in ();
+	}
+      else
+	{
+	  dp=my_init_dialog (d,choix);
+	}
+
+      show_mouse(screen);
+      while (my_update_dialog (dp))
+	;
+      choix=shutdown_dialog (dp);
+
+      play_click();
+
       switch (choix)
 	{
 	case -1:
@@ -143,6 +170,20 @@ int options (void)
 	  break;
 	case 10:
 	  load_default_options ();
+
+	  /*
+	   * The volume might have changed, so we update it
+	   */
+	  WATER_VOLUME=CONFIG_WATER_VOLUME_MENU;
+	  /*
+	   * If the graphics settings changed, we reflect them
+	   */
+	  if (old_gfx_menu!=CONFIG_GFX_MENU ||
+	      old_fullscreen!=CONFIG_FULLSCREEN)
+	    {
+	      gfxmode_change=1;
+	      set_resolution(CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN,NULL);
+	    }
 	  retour=0;
 	  break;
 	}
