@@ -434,7 +434,18 @@ int lw_protocol_waiting (int sock, int *waited_teams)
   int ret;
   LW_NETMESS *netmess;
 
-  (*waited_teams)=0;
+  /*
+   * Previous versions of LW used to set "waited teams" to
+   * 0 here. This caused weird bugs since this affectation
+   * is done in a separate thread, so the main thread would
+   * see "waited_teams==0" and then would try to start a game...
+   * All this ended in an "Error processing WHO 0" on the server.
+   * So it's very important *not* to set it to 0. We do not need
+   * to set it to any value in fact...
+   */
+  /*
+   * (*waited_teams)=NB_TEAMS;
+   */
 
   if (lw_sock_send_str(sock,LW_NETMESS_TEXT_WAITING))
     {
