@@ -74,6 +74,37 @@
 /* fonctions                                                        */
 /*==================================================================*/
 
+/*------------------------------------------------------------------*/
+static void write_cis_setting (DIALOG *d)
+{
+  char *str;
+
+  str=d->dp;
+  sprintf (str,
+	   "%s x%d",
+	   lw_lang_string(LW_LANG_STRING_RULES_CURSOR),
+	   CONFIG_CURSOR_INCREASE_SPEED+1);
+}
+
+/*------------------------------------------------------------------*/
+static int slider_cis (void *dp3, int d2)
+{
+  DIALOG *d;
+
+  d=dp3;
+
+  CONFIG_CURSOR_INCREASE_SPEED=d2;
+  write_cis_setting (d);
+
+  scare_mouse();
+  my_textbox_proc (MSG_DRAW, d, 0);
+  unscare_mouse();
+
+  play_click ();
+
+  return 0;
+}
+
 /*------------------------------------------------------------------*/
 static void write_time_setting (DIALOG *d)
 {
@@ -109,52 +140,102 @@ static int slider_time (void *dp3, int d2)
   return 0;
 }
 
+/*------------------------------------------------------------------*/
+static void write_mmr_setting (DIALOG *d)
+{
+  char *str;
+
+  str=d->dp;
+  sprintf (str,
+	   "%s%dx%d",
+	   lw_lang_string(LW_LANG_STRING_RULES_MINMAPRES),
+	   MIN_MAP_RES_W[CONFIG_MIN_MAP_RES],
+	   MIN_MAP_RES_H[CONFIG_MIN_MAP_RES]);
+}
+
+/*------------------------------------------------------------------*/
+static int slider_mmr (void *dp3, int d2)
+{
+  DIALOG *d;
+
+  d=dp3;
+
+  CONFIG_MIN_MAP_RES=d2;
+  write_mmr_setting (d);
+
+  scare_mouse();
+  my_textbox_proc (MSG_DRAW, d, 0);
+  unscare_mouse();
+
+  play_click ();
+
+  return 0;
+}
+
 /*------------------------------------------------------------------*/
 int rules_options (void)
 {
   int *temp;
-  DIALOG d[10];
+  DIALOG d[15];
   int i,choix=4,retour=0;
-  static int y_pos[3]={0,1,3};
+  static int y_pos[4]={0,1,2,3};
+  char cis_buffer[30];
   char time_str[14];
+  char mmr_buffer[50];
   
   memset(d,0,sizeof(d));
 
   sprintf(time_str,"%-8s00:00",lw_lang_string(LW_LANG_STRING_RULES_TIME));
 
-  for (i=0; i<2; ++i)
+  for (i=0; i<4; ++i)
     {
-      standard_button (d+i+4,0,y_pos[i],2,4);
+      standard_button (d+i+4,0,y_pos[i],2,8);
       d[i+4].proc=my_textbox_proc;
     }
-  for (i=0; i<2; ++i)
+  for (i=0; i<4; ++i)
     {
-      standard_button (d+i+6,1,y_pos[i],2,4);
-      d[i+6].proc=my_slider_proc;
+      standard_button (d+i+8,1,y_pos[i],2,8);
+      d[i+8].proc=my_slider_proc;
     }
 
-  standard_button (d+8,0,3,1,4);
-  d[8].dp=lw_lang_string(LW_LANG_STRING_RULES_ADVANCED);
+  standard_button (d+12,0,5,1,8);
+  d[12].dp=lw_lang_string(LW_LANG_STRING_RULES_ADVANCED);
+
+  standard_button (d+13,0,7,1,8);
+  d[13].dp=lw_lang_string(LW_LANG_STRING_RULES_DEFAULT);
 
   quick_buttons(d);
-  d[4].dp=lw_lang_string(LW_LANG_STRING_RULES_ARMYSIZE);
-  d[5].dp=time_str;
-  d[6].d1=32;
-  d[7].d1=16;
-  d[6].dp3=&CONFIG_FIGHTER_NUMBER;
-  d[7].dp3=&CONFIG_GAME_TIME;
-  for (i=6;i<8;++i)
+  d[4].dp=time_str;
+  d[5].dp=lw_lang_string(LW_LANG_STRING_RULES_ARMYSIZE);
+  d[6].dp=cis_buffer;
+  d[7].dp=mmr_buffer;
+  d[8].d1=16;
+  d[9].d1=32;
+  d[10].d1=2;
+  d[11].d1=8;
+  d[8].dp3=&CONFIG_GAME_TIME;
+  d[9].dp3=&CONFIG_FIGHTER_NUMBER;
+  d[10].dp3=&CONFIG_CURSOR_INCREASE_SPEED;
+  d[11].dp3=&CONFIG_MIN_MAP_RES;
+  for (i=8;i<12;++i)
     {
       d[i].dp=NULL;
       d[i].dp2=slider_int;
       temp=d[i].dp3;
       d[i].d2=*temp;
     }
-  d[7].dp2=slider_time;
-  d[7].dp3=d+5;
-  write_time_setting (d+5);
+  d[8].dp2=slider_time;
+  d[8].dp3=d+4;
+  d[10].dp2=slider_cis;
+  d[10].dp3=d+6;
+  d[11].dp2=slider_mmr;
+  d[11].dp3=d+7;
+
+  write_time_setting (d+4);
+  write_cis_setting (d+6);
+  write_mmr_setting (d+7);
  
-  d[9].proc=0;
+  d[14].proc=0;
 
   while (retour==0)
     {
@@ -175,9 +256,25 @@ int rules_options (void)
 	case MENU_QUICK_PLAY:
 	  retour=MENU_PLAY;
 	  break;
-	case 8 :
+	case 12 :
 	  retour=advanced_options();
 	  break;
+	case 13 :
+	  load_default_rules();
+	  
+	  /*
+	   * Needed because the slider function works in a weird way
+	   */
+	  LW_CONFIG_CURRENT_RULES.game_time=CONFIG_GAME_TIME;
+
+	  d[8].d2=CONFIG_GAME_TIME;
+	  d[9].d2=CONFIG_FIGHTER_NUMBER;
+	  d[10].d2=CONFIG_CURSOR_INCREASE_SPEED;
+	  d[11].d2=CONFIG_MIN_MAP_RES;
+	  write_time_setting (d+4);
+	  write_cis_setting (d+6);
+	  write_mmr_setting (d+7);
+	  break;
 	}
     }
 
