@@ -54,6 +54,7 @@
 
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "army.h"
 #include "back.h"
@@ -70,11 +71,21 @@
 #include "ticker.h"
 #include "log.h"
 #include "lang.h"
+#include "checksum.h"
+#include "startup.h"
+
+/*==================================================================*/
+/* constants                                                        */
+/*==================================================================*/
+
+#define LW_SCORE_TOMBOLA_MAX 500
 
 /*==================================================================*/
 /* variables globales                                               */
 /*==================================================================*/
 
+int LW_SCORE_TOMBOLA_RESULT[NB_TEAMS];
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -117,6 +128,7 @@ static int get_cursor (int classement)
 static void write_score (int indice, char *buffer,int fill_level)
 {
   int time,min,sec,pourmille,pourcent,decimale,l;
+  int tombola;
 
   if (indice>=0)
     {
@@ -125,42 +137,66 @@ static void write_score (int indice, char *buffer,int fill_level)
       if (fill_level>1000)
 	fill_level=1000;
 
-      if (CURRENT_CURSOR[indice].score_order==1
-	  && PLAYING_TEAMS==1)
-	strcpy (buffer,lw_lang_string(LW_LANG_STRING_SCORE_WINNER));
-      else
+      if (!STARTUP_TOMBOLA)
 	{
-	  if (CURRENT_CURSOR[indice].loose_time<=0)
-	    {
-	      pourmille= (ACTIVE_FIGHTERS[CURRENT_CURSOR[indice].team]*fill_level)
-                /CURRENT_ARMY_SIZE;
-	      pourcent=pourmille/10;
-	      decimale=pourmille%10;
-	      sprintf (buffer,"%d",pourcent);
-	      l=strlen (buffer);
-	      buffer [l]='.';
-	      buffer [l+1]='0'+decimale;
-	      buffer [l+2]='%';
-	      buffer [l+3]=0;
-	    }
+	  if (CURRENT_CURSOR[indice].score_order==1
+	      && PLAYING_TEAMS==1)
+	    strcpy (buffer,lw_lang_string(LW_LANG_STRING_SCORE_WINNER));
 	  else
 	    {
-	      time=(CURRENT_CURSOR[indice].loose_time*fill_level)/1000;
-	      min=time/60;
-	      sec=time%60;
-	      buffer[0]='0'+min/10;
-	      buffer[1]='0'+min%10;
-	      buffer[2]=':';
-	      buffer[3]='0'+sec/10;
-	      buffer[4]='0'+sec%10;
-	      buffer[5]=0;
+	      if (CURRENT_CURSOR[indice].loose_time<=0)
+		{
+		  pourmille= (ACTIVE_FIGHTERS[CURRENT_CURSOR[indice].team]*fill_level)
+		    /CURRENT_ARMY_SIZE;
+		  pourcent=pourmille/10;
+		  decimale=pourmille%10;
+		  sprintf (buffer,"%d",pourcent);
+		  l=strlen (buffer);
+		  buffer [l]='.';
+		  buffer [l+1]='0'+decimale;
+		  buffer [l+2]='%';
+		  buffer [l+3]=0;
+		}
+	      else
+		{
+		  time=(CURRENT_CURSOR[indice].loose_time*fill_level)/1000;
+		  min=time/60;
+		  sec=time%60;
+		  buffer[0]='0'+min/10;
+		  buffer[1]='0'+min%10;
+		  buffer[2]=':';
+		  buffer[3]='0'+sec/10;
+		  buffer[4]='0'+sec%10;
+		  buffer[5]=0;
+		}
 	    }
 	}
+      else
+	{
+	  /*
+	   * OK, we're in "tombola" mode, so we display a random
+	   * number instead of the score.
+	   */
+
+	  tombola = (LW_SCORE_TOMBOLA_RESULT[indice]*fill_level)/1000;
+	  sprintf(buffer,"%03d",tombola);
+	}
     }
   else
     buffer[0]=0;
 }
 
+/*------------------------------------------------------------------*/
+static void init_tombola()
+{
+  int i;
+
+  for (i=0;i<NB_TEAMS;++i)
+    {
+      LW_SCORE_TOMBOLA_RESULT[i]=rand()%LW_SCORE_TOMBOLA_MAX+1;
+    }
+}
+
 /*------------------------------------------------------------------*/
 static int draw_score_bitmap (BITMAP *bitmap, int cursor,
 			      int ellipse_h,
@@ -272,6 +308,8 @@ int display_scores (void)
 
   d[10].proc=NULL;
 
+  init_tombola();
+
   ellipse_h=d[4].h;
   y=d[4].y-menu_real_y(MENU_H_SPACE);
   h[1]=2*y-SCREEN_H;
@@ -376,7 +414,7 @@ int display_scores (void)
 	  d[MENU_QUICK_QUIT].flags=D_EXIT;
 	  d[MENU_QUICK_PLAY].flags=D_EXIT;
 	  choix= my_do_dialog_no_clear(d,
-				       last_draw_done==1 ? MENU_QUICK_MAIN
+				       last_draw_done==1 ? MENU_QUICK_BACK
 				       : choix);
 	  last_draw_done=2;
 	}
