@@ -369,7 +369,8 @@ int main(int argc, char **argv)
 	      if (lw_srvcont_wait_teams(&cont, 
 					&www_data,
 					nb_teams, 
-					port))
+					port,
+					get_password()))
 		{
 		  if (lw_srvcont_tell_who(&cont))
 		    {
@@ -378,7 +379,8 @@ int main(int argc, char **argv)
 			  res=lw_srvcont_replicate_keys
 			    (&cont, 
 			     &www_data,
-			     get_lag());
+			     get_lag(),
+			     get_password());
 			}
 		    }
 		}
