@@ -73,37 +73,6 @@
 /* fonctions                                                        */
 /*==================================================================*/
 
-/*------------------------------------------------------------------*/
-static void write_cis_setting (DIALOG *d)
-{
-  char *str;
-
-  str=d->dp;
-  sprintf (str,
-	   "%s x%d",
-	   lw_lang_string(LW_LANG_STRING_SPEEDS_CURSOR),
-	   CONFIG_CURSOR_INCREASE_SPEED+1);
-}
-
-/*------------------------------------------------------------------*/
-static int slider_cis (void *dp3, int d2)
-{
-  DIALOG *d;
-
-  d=dp3;
-
-  CONFIG_CURSOR_INCREASE_SPEED=d2;
-  write_cis_setting (d);
-
-  scare_mouse();
-  my_textbox_proc (MSG_DRAW, d, 0);
-  unscare_mouse();
-
-  play_click ();
-
-  return 0;
-}
-
 /*------------------------------------------------------------------*/
 static void write_fps_setting (DIALOG *d)
 {
@@ -185,53 +154,47 @@ static int slider_rps (void *dp3, int d2)
 int speeds_options (void)
 {
   int *temp;
-  DIALOG d[11];
+  DIALOG d[9];
   int i,choix=4,retour=0;
-  char cis_buffer[30];
   char fps_buffer[30];
   char rps_buffer[30];
   
   memset(d,0,sizeof(d));
 
-  for (i=0; i<3; ++i)
+  for (i=0; i<2; ++i)
     {
-      standard_button (d+i+4,0,i,2,3);
+      standard_button (d+i+4,0,i,2,2);
       d[i+4].proc=my_textbox_proc;
     }
-  for (i=0; i<3; ++i)
+  for (i=0; i<2; ++i)
     {
-      standard_button (d+i+7,1,i,2,3);
-      d[i+7].proc=my_slider_proc;
+      standard_button (d+i+6,1,i,2,2);
+      d[i+6].proc=my_slider_proc;
     }
 
   quick_buttons(d);
-  d[4].dp=cis_buffer;
-  d[5].dp=fps_buffer;
-  d[6].dp=rps_buffer;
-  d[7].d1=2;
-  d[8].d1=8;
-  d[9].d1=8;
-  d[7].dp3=&CONFIG_CURSOR_INCREASE_SPEED;
-  d[8].dp3=&CONFIG_FRAMES_PER_SEC_LIMIT;
-  d[9].dp3=&CONFIG_ROUNDS_PER_SEC_LIMIT;
-  for (i=0;i<3;++i)
+  d[4].dp=fps_buffer;
+  d[5].dp=rps_buffer;
+  d[6].d1=8;
+  d[7].d1=8;
+  d[6].dp3=&CONFIG_FRAMES_PER_SEC_LIMIT;
+  d[7].dp3=&CONFIG_ROUNDS_PER_SEC_LIMIT;
+  for (i=0;i<2;++i)
     {
-      d[i+7].dp=NULL;
-      d[i+7].dp2=slider_int;
-      temp=d[i+7].dp3;
-      d[i+7].d2=*temp;
-      d[i+7].dp3=d+i+4;
+      d[i+6].dp=NULL;
+      d[i+6].dp2=slider_int;
+      temp=d[i+6].dp3;
+      d[i+6].d2=*temp;
+      d[i+6].dp3=d+i+4;
     }
 
-  d[7].dp2=slider_cis; 
-  d[8].dp2=slider_fps; 
-  d[9].dp2=slider_rps; 
+  d[6].dp2=slider_fps; 
+  d[7].dp2=slider_rps; 
 
-  write_cis_setting(d+4);
-  write_fps_setting(d+5);
-  write_rps_setting(d+6);
+  write_fps_setting(d+4);
+  write_rps_setting(d+5);
 
-  d[10].proc=0;
+  d[8].proc=0;
 
   while (retour==0)
     {
