@@ -103,6 +103,7 @@ static void find_chan_and_team_by_server_id(LW_SRVCONT *cont,
 static int send_lag_key_presses(LW_SRVCONT *cont,int lag);
 static int reject_new_clients(LW_SRVCONT *cont, char *password);
 static void reject_new_clients_callback(void *args);
+static void disconnect_client(LW_SRVCONT *cont, int i, char *reason);
 
 /*------------------------------------------------------------------*/
 /*
@@ -321,7 +322,7 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
 {
   int free_teams=0;
   int result=0;
-  int i,j;
+  int i;
   int start;
   int started=0;
   LW_TEAMSTARTINFO team_start_info[NB_TEAMS];
@@ -458,19 +459,7 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
 		   * There's an error with this client, so 
 		   * we're simply going to disconnect it...
 		   */
-		  log_print_str("Disconnecting \"");
-		  log_print_str(cont->chan[i].ip);
-		  log_print_str(":");
-		  log_print_int(cont->chan[i].port);
-		  log_print_str("\"");
-		  log_println();		  
-
-		  lw_srvchan_close(&(cont->chan[i]));
-		  for (j=i+1;j<cont->nb_chans;++j)
-		    {
-		      cont->chan[j-1]=cont->chan[j];
-		    }
-		  cont->nb_chans--;
+		  disconnect_client(cont,i,"keepalive failed");
 
 		  display_waiting_for=1;
 		}
@@ -523,7 +512,7 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
  */
 int lw_srvcont_tell_who(LW_SRVCONT *cont)
 {
-  int i,j;
+  int i;
   int result=0;
 
   if (distribute_teams(cont))
@@ -539,29 +528,17 @@ int lw_srvcont_tell_who(LW_SRVCONT *cont)
 	       * There's been an error exchanging data with this team
 	       * so we decide to "close" it.
 	       */
-	      log_print_str("Disconnecting \"");
-	      log_print_str(cont->chan[i].ip);
-	      log_print_str(":");
-	      log_print_int(cont->chan[i].port);
-	      log_print_str("\"");
-	      log_println();
-
-	      lw_srvchan_close(&(cont->chan[i]));
-	      for (j=i+1;j<cont->nb_chans;++j)
-		{
-		  cont->chan[j-1]=cont->chan[j];
-		}
-	      cont->nb_chans--;
+	      disconnect_client(cont,i,"can't send game info");
 	    }
 	}
-    }
 
-  /*
-   * We start the game only if there are more than 1 channels opened...
-   */
-  if (cont->nb_chans>0)
-    {
-      result=1;
+      /*
+       * We start the game only if there are more than 1 channels opened...
+       */
+      if (cont->nb_chans>0)
+	{
+	  result=1;
+	}
     }
 
   return result;
@@ -575,16 +552,24 @@ int lw_srvcont_tell_who(LW_SRVCONT *cont)
 int lw_srvcont_final_ok(LW_SRVCONT *cont)
 {
   int i;
-  int result=1;
+  int result=0;
 
-  for (i=0;i<cont->nb_chans;++i)
+  for (i=cont->nb_chans-1;i>=0;--i)
     {
       if (!lw_srvchan_final_ok(&(cont->chan[i])))
 	{
-	  result=0;
+	  disconnect_client(cont,i,"can't send final ok");
 	}
     }
 
+  /*
+   * We start the game only if there are more than 1 channels opened...
+   */
+  if (cont->nb_chans>0)
+    {
+      result=1;
+    }
+
   if (result)
     {
       log_print_str("Game start");
@@ -617,7 +602,7 @@ static int send_lag_key_presses(LW_SRVCONT *cont,int lag)
 
   for (j=0;j<lag && result;++j)
     {
-      for (i=0;i<cont->nb_chans && result;++i)
+      for (i=cont->nb_chans-1;i>=0;--i)
 	{
 	  /*
 	   * We put the checksum to 1, to inform the clients that
@@ -626,7 +611,7 @@ static int send_lag_key_presses(LW_SRVCONT *cont,int lag)
 	  cont->chan[i].checksum_send=1;
 	  if (!lw_srvchan_send_keys(&(cont->chan[i]),&netkey))
 	    {
-	      result=0;
+	      disconnect_client(cont,i,"error sending lag keys");
 	    }
 	}
     }
@@ -648,32 +633,41 @@ int check_checksum(LW_SRVCONT *cont)
     {
       cont->chan[i].checksum_send=1;
       nb_diff=0;
-      for (j=0;j<cont->nb_chans;++j)
+      
+      /*
+       * We do not check checksums if there's only 1 connected client.
+       */
+      if (cont->nb_chans>=2)
 	{
-	  if (cont->chan[i].checksum_recv != cont->chan[j].checksum_recv)
+	  for (j=0;j<cont->nb_chans;++j)
 	    {
-	      ok=0;
-	      nb_diff++;
-
-	      /*
-	       * Now if this channels has a different checksum
-	       * than everyone else, we consider there's an error
-	       * on it. But if there's at least one channel that
-	       * has the same checksum, we consider it's OK
-	       * (for this channel only of course...)
-	       */
-	      if (nb_diff>=cont->nb_chans-1)
+	      if (cont->chan[i].checksum_recv != cont->chan[j].checksum_recv)
 		{
-		  cont->chan[i].checksum_send=0;
-
-		  log_print_str("Checksum error on client \"");
-		  log_print_str(cont->chan[i].ip);
-		  log_print_str(":");
-		  log_print_int(cont->chan[i].port);
-		  log_print_str("\"");
-		  log_println();
+		  ok=0;
+		  nb_diff++;
 		}
 	    }
+
+	  /*
+	   * Now if this channel has a different checksum
+	   * than everyone else, we consider there's an error
+	   * on it. But if there's at least one channel that
+	   * has the same checksum, we consider it's OK
+	   * (for this channel only of course...)
+	   */
+	  if (nb_diff>=cont->nb_chans-1)
+	    {
+	      cont->chan[i].checksum_send=0;
+	      
+	      log_print_str("Checksum error on client \"");
+	      log_print_str(cont->chan[i].ip);
+	      log_print_str(":");
+	      log_print_int(cont->chan[i].port);
+	      log_print_str("\" (");
+	      log_print_int(cont->chan[i].checksum_recv);
+	      log_print_str(")");
+	      log_println();
+	    }
 	}
     }
 
@@ -691,7 +685,7 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
 {
   int result=1;
   LW_NETKEY netkey;
-  int i,j;
+  int i;
   int increase_lag_counter=0;
   int decrease_lag_counter=0;
   int all_clients_request_increase_lag;
@@ -767,19 +761,7 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
 	       * There's been an error receiving data from this team
 	       * so we decide to "close" it.
 	       */
-	      log_print_str("Disconnecting \"");
-	      log_print_str(cont->chan[i].ip);
-	      log_print_str(":");
-	      log_print_int(cont->chan[i].port);
-	      log_print_str("\"");
-	      log_println();
-
-	      lw_srvchan_close(&(cont->chan[i]));
-	      for (j=i+1;j<cont->nb_chans;++j)
-		{
-		  cont->chan[j-1]=cont->chan[j];
-		}
-	      cont->nb_chans--;
+	      disconnect_client(cont,i,"no more keys");
 	    }
 	}
 
@@ -872,19 +854,7 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
 		   * There's been an error receiving data from this team
 		   * so we decide to "close" it.
 		   */
-		  log_print_str("Disconnecting \"");
-		  log_print_str(cont->chan[i].ip);
-		  log_print_str(":");
-		  log_print_int(cont->chan[i].port);
-		  log_print_str("\"");
-		  log_println();
-
-		  lw_srvchan_close(&(cont->chan[i]));
-		  for (j=i+1;j<cont->nb_chans;++j)
-		    {
-		      cont->chan[j-1]=cont->chan[j];
-		    }
-		  cont->nb_chans--;
+		  disconnect_client(cont,i,"error sending keys");
 		}
 	    }
 	}
@@ -1110,4 +1080,27 @@ static void reject_new_clients_callback(void *args)
   (*(data.thread_running))=0;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Disconnects a client. This code supposes that the caller function
+ * is executing a loop with a step of -1 (ie a "reverse" loop).
+ */
+static void disconnect_client(LW_SRVCONT *cont, int i, char *reason)
+{
+  int j;
+
+  log_print_str("Disconnecting \"");
+  log_print_str(cont->chan[i].ip);
+  log_print_str(":");
+  log_print_int(cont->chan[i].port);
+  log_print_str("\" (");
+  log_print_str(reason);
+  log_println_str(")");
   
+  lw_srvchan_close(&(cont->chan[i]));
+  for (j=i+1;j<cont->nb_chans;++j)
+    {
+      cont->chan[j-1]=cont->chan[j];
+    }
+  cont->nb_chans--;
+}
