@@ -67,6 +67,7 @@
 #include "team.h"
 #include "log.h"
 #include "lang.h"
+#include "netmess.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -211,26 +212,10 @@ static char *MENU_KEY_NAMES[]={
 static void cleanup_player_names ()
 {
   int i;
-  char *pos;
-  char c;
 
   for (i=0;i<NB_TEAMS;++i)
     {
-      pos=CONFIG_PLAYER_NAME[i];
-
-      while ((c=*pos)!='\0')
-	{
-	  
-	  if (! (isalnum(c) ||
-		 c == ' ' ||
-		 c == '-' ||
-		 c == '_'))
-	    {
-	      (*pos)=' ';
-	    }
-	  
-	  pos++;
-	}
+      lw_netmess_cleanup_arg(CONFIG_PLAYER_NAME[i]);
     }
 }
 
