@@ -113,10 +113,8 @@ int sound_options (void)
       temp=d[i].dp3;
       d[i].d2=*temp;
     }
- 
-  d[14].proc=0;
 
-  CONFIG_WATER_VOLUME_MENU=WATER_VOLUME;
+  d[14].proc=0;
 
   while (retour==0)
     {
@@ -142,6 +140,8 @@ int sound_options (void)
 	}
     }
 
+  CONFIG_WATER_VOLUME_MENU=WATER_VOLUME;	// realign current volume
+						// and config volume
   if (retour>0)
     retour--;
 
