@@ -373,11 +373,16 @@ void write_to_disk (char *str)
       w=DST_W;
       h=DST_H;
       size=DST_SIZE;
-      fwrite (&BG_SIZE,4,1,f);
+      /*
+       * Previous versions of LW used to store the size of
+       * the background here, to sort map afterwards. Now
+       * we store the size of the map.
+       */
+      fwrite (&size,4,1,f);
       fwrite (&w,2,1,f);
       fwrite (&h,2,1,f);
       fwrite (READABLE_NAME,sizeof(READABLE_NAME),1,f);
-      fwrite (BUFFER,DST_SIZE,1,f);
+      fwrite (BUFFER,size,1,f);
       fclose (f);
     }
   else
